#[derive(MultiSend)]Expand description
Derives the ability to use this struct of Senders and AsyncSenders to
call .send or .send_async directly as if using one of the included
Senders or AsyncSenders.
#[derive(MultiSend)]Derives the ability to use this struct of Senders and AsyncSenders to
call .send or .send_async directly as if using one of the included
Senders or AsyncSenders.